==> zio-aws-transcribe_2.13-7.21.15.8-sources.jar: zio/aws/transcribe/model/ListVocabulariesRequest.scala <==
package zio.aws.transcribe.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.transcribe.model.primitives.{
  VocabularyName,
  MaxResults,
  NextToken
}
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class ListVocabulariesRequest(
    nextToken: Optional[NextToken] = Optional.Absent,
    maxResults: Optional[MaxResults] = Optional.Absent,
    stateEquals: Optional[zio.aws.transcribe.model.VocabularyState] =
      Optional.Absent,
    nameContains: Optional[VocabularyName] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.transcribe.model.ListVocabulariesRequest = {
    import ListVocabulariesRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.transcribe.model.ListVocabulariesRequest
      .builder()
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .optionallyWith(
        maxResults.map(value => MaxResults.unwrap(value): Integer)
      )(_.maxResults)
      .optionallyWith(stateEquals.map(value => value.unwrap))(_.stateEquals)
      .optionallyWith(
        nameContains.map(value =>
          VocabularyName.unwrap(value): java.lang.String
        )
      )(_.nameContains)
      .build()
  }
  def asReadOnly: zio.aws.transcribe.model.ListVocabulariesRequest.ReadOnly =
    zio.aws.transcribe.model.ListVocabulariesRequest.wrap(buildAwsValue())
}
object ListVocabulariesRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.transcribe.model.ListVocabulariesRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.transcribe.model.ListVocabulariesRequest =
      zio.aws.transcribe.model.ListVocabulariesRequest(
        nextToken.map(value => value),
        maxResults.map(value => value),
        stateEquals.map(value => value),
        nameContains.map(value => value)
      )
    def nextToken: Optional[NextToken]
    def maxResults: Optional[MaxResults]
    def stateEquals: Optional[zio.aws.transcribe.model.VocabularyState]
    def nameContains: Optional[VocabularyName]
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getMaxResults: ZIO[Any, AwsError, MaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getStateEquals
        : ZIO[Any, AwsError, zio.aws.transcribe.model.VocabularyState] =
      AwsError.unwrapOptionField("stateEquals", stateEquals)
    def getNameContains: ZIO[Any, AwsError, VocabularyName] =
      AwsError.unwrapOptionField("nameContains", nameContains)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.transcribe.model.ListVocabulariesRequest
  ) extends zio.aws.transcribe.model.ListVocabulariesRequest.ReadOnly {
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.transcribe.model.primitives.NextToken(value))
    override val maxResults: Optional[MaxResults] = zio.aws.core.internal
      .optionalFromNullable(impl.maxResults())
      .map(value => zio.aws.transcribe.model.primitives.MaxResults(value))
    override val stateEquals
        : Optional[zio.aws.transcribe.model.VocabularyState] =
      zio.aws.core.internal
        .optionalFromNullable(impl.stateEquals())
        .map(value => zio.aws.transcribe.model.VocabularyState.wrap(value))
    override val nameContains: Optional[VocabularyName] = zio.aws.core.internal
      .optionalFromNullable(impl.nameContains())
      .map(value => zio.aws.transcribe.model.primitives.VocabularyName(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.transcribe.model.ListVocabulariesRequest
  ): zio.aws.transcribe.model.ListVocabulariesRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-transcribe_3-5.17.104.4-sources.jar: zio/aws/transcribe/model/ListVocabulariesRequest.scala <==
package zio.aws.transcribe.model
import java.lang.Integer
import zio.ZIO
import zio.aws.transcribe.model.primitives.{
  VocabularyName,
  MaxResults,
  NextToken
}
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class ListVocabulariesRequest(
    nextToken: Option[NextToken] = None,
    maxResults: Option[MaxResults] = None,
    stateEquals: Option[zio.aws.transcribe.model.VocabularyState] = None,
    nameContains: Option[VocabularyName] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.transcribe.model.ListVocabulariesRequest = {
    import ListVocabulariesRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.transcribe.model.ListVocabulariesRequest
      .builder()
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .optionallyWith(
        maxResults.map(value => MaxResults.unwrap(value): Integer)
      )(_.maxResults)
      .optionallyWith(stateEquals.map(value => value.unwrap))(_.stateEquals)
      .optionallyWith(
        nameContains.map(value =>
          VocabularyName.unwrap(value): java.lang.String
        )
      )(_.nameContains)
      .build()
  }
  def asReadOnly: zio.aws.transcribe.model.ListVocabulariesRequest.ReadOnly =
    zio.aws.transcribe.model.ListVocabulariesRequest.wrap(buildAwsValue())
}
object ListVocabulariesRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.transcribe.model.ListVocabulariesRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.transcribe.model.ListVocabulariesRequest =
      zio.aws.transcribe.model.ListVocabulariesRequest(
        nextToken.map(value => value),
        maxResults.map(value => value),
        stateEquals.map(value => value),
        nameContains.map(value => value)
      )
    def nextToken: Option[NextToken]
    def maxResults: Option[MaxResults]
    def stateEquals: Option[zio.aws.transcribe.model.VocabularyState]
    def nameContains: Option[VocabularyName]
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getMaxResults: ZIO[Any, AwsError, MaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getStateEquals
        : ZIO[Any, AwsError, zio.aws.transcribe.model.VocabularyState] =
      AwsError.unwrapOptionField("stateEquals", stateEquals)
    def getNameContains: ZIO[Any, AwsError, VocabularyName] =
      AwsError.unwrapOptionField("nameContains", nameContains)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.transcribe.model.ListVocabulariesRequest
  ) extends zio.aws.transcribe.model.ListVocabulariesRequest.ReadOnly {
    override val nextToken: Option[NextToken] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.transcribe.model.primitives.NextToken(value))
    override val maxResults: Option[MaxResults] = scala
      .Option(impl.maxResults())
      .map(value => zio.aws.transcribe.model.primitives.MaxResults(value))
    override val stateEquals: Option[zio.aws.transcribe.model.VocabularyState] =
      scala
        .Option(impl.stateEquals())
        .map(value => zio.aws.transcribe.model.VocabularyState.wrap(value))
    override val nameContains: Option[VocabularyName] = scala
      .Option(impl.nameContains())
      .map(value => zio.aws.transcribe.model.primitives.VocabularyName(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.transcribe.model.ListVocabulariesRequest
  ): zio.aws.transcribe.model.ListVocabulariesRequest.ReadOnly = new Wrapper(
    impl
  )
}
